Base class for SDMX endpoints
SDMXEndpoint.RdCreate a:
a known endpoint from
endpointsuseget_endpoint().unlisted SDMX 2.1 REST endpoint use
sdmx_endpoint().a new SDMX endpoint use
SDMXEndpoint$new().
Base class for SDMX endpoints
See also
Other SDMX endpoints:
get_endpoint(),
sdmx_endpoint()
Public fields
reqhttr2::request()object, can be adjusted to add headers or proxy settingsversioncharacter, the SDMX version of the endpoint
idcharacter, the id of the endpoint
namecharacter, the name of the endpoint
urlcharacter, the url of the endpoint
verboselogical, if
TRUEprint information the connectioncache_dircharacter, the directory to cache the metadata in
languagecharacter, the language to use for the text used in the response
Methods
Method new()
create a new SDMXEndpoint object, see also sdmx_endpoint()
Usage
SDMXEndpoint$new(
url,
id = gsub("\\W+", "_", url),
name = url,
language = NULL,
cache_dir = file.path(tempdir(), "sdmxdata", id),
verbose = getOption("sdmxdata.verbose", FALSE)
)Arguments
urlcharacter, the url of the endpoint
idcharacter, the id of the endpoint
namecharacter, the name of the endpoint
languagecharacter, the language to use for the text used in the response
cache_dircharacter, the directory to cache the metadata in
verboselogical, if
TRUEprint information on the connection